@@ -1,8 +1,7 @@
 
 /*
 
-    File: smtp/ip-lib.h
-    Version 1.0
+    File: ip-lib.h
     
     Copyright (C) 1999 by Wolfgang Zekoll <wzk@quietsche-entchen.de>
 
@@ -28,10 +27,7 @@
 extern char *program;
 
 
-extern int ip_lib_error;
-
-char *get_error(int code);
-FILE *ip_open(char *server, unsigned int port);
+int openip(char *server, unsigned int port);
 unsigned int get_port(char *server, unsigned int def_port);
 int get_client_info(int pfd, char *ipnum, char *name);
 
