@@ -1,10 +1,9 @@
 
 /*
 
-    File: lib/lib.h
-    Version 1.0
+    File: lib.h
     
-    Copyright (C) 1998 by Wolfgang Zekoll <wzk@quietsche-entchen.de>
+    Copyright (C) 1998,1999 by Wolfgang Zekoll <wzk@quietsche-entchen.de>
 
     This source is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,6 +42,7 @@ char *skip_ws(char *string);
 char *noctrl(char *buffer);
 char *get_word(char **from, char *to, int maxlen);
 char *get_quoted(char **from, int delim, char *to, int max);
+int split(char *line, char **ptr, int sep, int max);
 char *copy_string(char *y, char *x, int len);
 int strpcmp(char *string, char *pattern);
 
